summaryrefslogtreecommitdiffstats
path: root/src/electronics/gpsimprocessor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/electronics/gpsimprocessor.h')
-rw-r--r--src/electronics/gpsimprocessor.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/electronics/gpsimprocessor.h b/src/electronics/gpsimprocessor.h
index 9939be4..e2f0e4c 100644
--- a/src/electronics/gpsimprocessor.h
+++ b/src/electronics/gpsimprocessor.h
@@ -252,7 +252,7 @@ class GpsimProcessor : public TQObject
public:
/**
* Create a new gpsim processor. After calling this constructor, you
* should always call codLoadtqStatus() to ensure that the cod file was
* loaded successfully.
*/
GpsimProcessor( TQString symbolFile, TQObject *parent = 0 );
@@ -261,7 +261,7 @@ class GpsimProcessor : public TQObject
void setDebugMode( GpsimDebugger::Type mode ) { m_debugMode = mode; }
GpsimDebugger * currentDebugger() const { return m_pDebugger[m_debugMode]; }
- enum CodLoadtqStatus
+ enum CodLoadStatus
{
CodSuccess,
CodFileNotFound,
@@ -284,14 +284,14 @@ class GpsimProcessor : public TQObject
/**
* @return status of opening the COD file
- * @see displayCodLoadtqStatus
+ * @see displayCodLoadStatus
*/
- CodLoadtqStatus codLoadtqStatus() const { return m_codLoadtqStatus; }
+ CodLoadStatus codLoadStatus() const { return m_codLoadStatus; }
/**
* Popups a messagebox to the user according to the CodLoadtqStatus. Will
* only popup a messagebox if the CodLoadtqStatus wasn't CodSuccess.
*/
- void displayCodLoadtqStatus();
+ void displayCodLoadStatus();
/**
* Returns a list of source files for the currently running program.
*/
@@ -373,7 +373,7 @@ class GpsimProcessor : public TQObject
void emitLineReached();
pic_processor * m_pPicProcessor;
- CodLoadtqStatus m_codLoadtqStatus;
+ CodLoadStatus m_codLoadStatus;
const TQString m_symbolFile;
RegisterSet * m_pRegisterMemory;
GpsimDebugger::Type m_debugMode;
@@ -252,7 +252,7 @@ class GpsimProcessor : public TQObject
/**
* Create a new gpsim processor. After calling this constructor, you
- * should always call codLoadtqStatus() to ensure that the cod file was
+ * should always call codLoadStatus() to ensure that the cod file was
* loaded successfully.
*/
@@ -284,14 +284,14 @@ class GpsimProcessor : public TQObject
/**
- * Popups a messagebox to the user according to the CodLoadtqStatus. Will
- * only popup a messagebox if the CodLoadtqStatus wasn't CodSuccess.
+ * Popups a messagebox to the user according to the CodLoadStatus. Will
+ * only popup a messagebox if the CodLoadStatus wasn't CodSuccess.
*/